@@ -25,7 +25,6 @@ use strict;
 use warnings;
 use File::Temp qw(tempdir);
 
-use Dpkg::Deps;
 use Sbuild qw(debug copy version_compare);
 use Sbuild::Base;
 use Sbuild::ResolverBase;
@@ -84,6 +83,7 @@ sub install_deps {
 	$self->get_conf('APTITUDE'),
 	'-y',
 	'--without-recommends',
+	'-o', 'Dpkg::Options::=--force-confold',
 	'-o', "Aptitude::CmdLine::Ignore-Trust-Violations=$ignore_trust_violations",
 	'-o', 'Aptitude::ProblemResolver::StepScore=100',
 	'-o', "Aptitude::ProblemResolver::SolutionCost=safety, priority, non-default-versions",
